@@ -55,10 +55,10 @@
 # include <sys/locking.h>
 #endif
 
-#include "exc.h"
-#include "dbg.h"
-#include "msg.h"
-#include "fio.h"
+#include "base/exc.h"
+#include "base/dbg.h"
+#include "base/msg.h"
+#include "base/fio.h"
 
 
 /* Define some POSIX functionality that is missing on W32 */
@@ -830,7 +830,7 @@ error_exit:
     std::string readline(FILE *f, const std::string &filename)
     {
         std::string line;
-        char c;
+        int c;
 
         while ((c = getc(f, filename)) != EOF)
         {
