@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
+ * Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -114,6 +114,7 @@ CMD_DECL(from_netpbm)
 CMD_DECL(from_pcd)
 CMD_DECL(from_pfs)
 CMD_DECL(from_ply)
+CMD_DECL(from_pmd)
 CMD_DECL(from_pvm)
 CMD_DECL(from_rat)
 CMD_DECL(from_raw)
@@ -151,6 +152,7 @@ CMD_DECL(to_sndfile)
 CMD_DECL(to_teem)
 CMD_DECL(uncompress)
 CMD_DECL(version)
+CMD_DECL(view)
 
 static cmd_t cmds[] =
 {
@@ -213,7 +215,7 @@ static cmd_t cmds[] =
     CMD("from-jpeg",         cmd_conversion, from_jpeg,         WITH_JPEG,     "conv-jpeg",
             "Import arrays from JPEG images"),
     CMD("from-magick",       cmd_conversion, from_magick,       WITH_MAGICK,   "conv-magick",
-            "Import arrays from images via ImageMagick"),
+            "Import arrays from images via " MAGICK_FLAVOR),
     CMD("from-mat",          cmd_conversion, from_mat,          WITH_MAT,      "conv-mat",
             "Import arrays from Matlab files"),
     CMD("from-netcdf",       cmd_conversion, from_netcdf,       WITH_NETCDF,   "conv-netcdf",
@@ -226,6 +228,8 @@ static cmd_t cmds[] =
             "Import arrays from PFS images"),
     CMD("from-ply",          cmd_conversion, from_ply,          WITH_PLY,      "conv-ply",
             "Import arrays from PLY point data"),
+    CMD("from-pmd",          cmd_conversion, from_pmd,          WITH_PMD,      "conv-pmd",
+            "Import arrays from PMD ToF sensor data files"),
     CMD("from-pvm",          cmd_conversion, from_pvm,          WITH_PVM,      "conv-pvm",
             "Import arrays from PVM volume data"),
     CMD("from-rat",          cmd_conversion, from_rat,          WITH_RAT,      "conv-rat",
@@ -273,7 +277,7 @@ static cmd_t cmds[] =
     CMD("to-jpeg",           cmd_conversion, to_jpeg,           WITH_JPEG,     "conv-jpeg",
             "Export arrays to JPEG images"),
     CMD("to-magick",         cmd_conversion, to_magick,         WITH_MAGICK,   "conv-magick",
-            "Export arrays to images via ImageMagick"),
+            "Export arrays to images via " MAGICK_FLAVOR),
     CMD("to-mat",            cmd_conversion, to_mat,            WITH_MAT,      "conv-mat",
             "Export arrays to Matlab files"),
     CMD("to-netcdf",         cmd_conversion, to_netcdf,         WITH_NETCDF,   "conv-netcdf",
@@ -300,6 +304,8 @@ static cmd_t cmds[] =
             "Uncompress arrays"),
     CMD("version",           cmd_misc,       version,           true,          BUILTIN,
             "Show program version"),
+    CMD("view",              cmd_misc,       view,              WITH_QTOPENGL && WITH_GLEWMX,   "view",
+            "Visualize GTAs"),
 };
 
 
@@ -415,11 +421,23 @@ int cmd_run(int cmd_index, int argc, char *argv[])
     return cmds[cmd_index].cmd(argc, argv);
 }
 
+#if DYNAMIC_MODULES
+void* cmd_symbol(int cmd_index, const char* symbol)
+{
+    return dlsym(cmds[cmd_index].module_handle, symbol);
+}
+#endif
+
 void cmd_close(int cmd_index)
 {
 #if DYNAMIC_MODULES
     if (cmds[cmd_index].module_handle)
     {
+        // XXX HACK for Qt5: do not close a module using Qt5 because that library
+        // seems to register atexit() handlers, which results in a jump to an
+        // invalid address when main() returns but the handlers are not present anymore.
+        if (strcmp(cmds[cmd_index].name, "gui") == 0)
+            return;
         (void)dlclose(cmds[cmd_index].module_handle);
         cmds[cmd_index].module_handle = NULL;
         cmds[cmd_index].cmd_print_help = NULL;
