@@ -29,12 +29,12 @@
 
 #include <muParser.h>
 
-#include "msg.h"
-#include "blob.h"
-#include "opt.h"
-#include "fio.h"
-#include "str.h"
-#include "intcheck.h"
+#include "base/msg.h"
+#include "base/blb.h"
+#include "base/opt.h"
+#include "base/fio.h"
+#include "base/str.h"
+#include "base/chk.h"
 
 #include "lib.h"
 
