@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2012, 2013
+ * Copyright (C) 2012, 2013, 2014
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,9 @@ extern "C" void gtatool_to_csv_help(void)
     msg::req_txt("to-csv [-D|--delimiter=D] [<input-file>] <output-file>\n"
             "\n"
             "Converts GTAs to csv format, using the field delimiter D. "
-            "D is a single ASCII character; the default is the comma (',').");
+            "D is a single ASCII character; the default is the comma (',').\n"
+            "If more than one array is available in the input, the arrays will "
+            "be separated by blank lines in the output.");
 }
 
 static void write_component(const void* c, gta::type t, char s[32])
@@ -55,49 +57,49 @@ static void write_component(const void* c, gta::type t, char s[32])
     {
         int8_t v;
         std::memcpy(&v, c, sizeof(int8_t));
-        snprintf(s, 32, "%"PRId8, v);
+        snprintf(s, 32, "%" PRId8, v);
     }
     else if (t == gta::uint8)
     {
         uint8_t v;
         std::memcpy(&v, c, sizeof(uint8_t));
-        snprintf(s, 32, "%"PRIu8, v);
+        snprintf(s, 32, "%" PRIu8, v);
     }
     else if (t == gta::int16)
     {
         int16_t v;
         std::memcpy(&v, c, sizeof(int16_t));
-        snprintf(s, 32, "%"PRId16, v);
+        snprintf(s, 32, "%" PRId16, v);
     }
     else if (t == gta::uint16)
     {
         uint16_t v;
         std::memcpy(&v, c, sizeof(uint16_t));
-        snprintf(s, 32, "%"PRIu16, v);
+        snprintf(s, 32, "%" PRIu16, v);
     }
     else if (t == gta::int32)
     {
         int32_t v;
         std::memcpy(&v, c, sizeof(int32_t));
-        snprintf(s, 32, "%"PRId32, v);
+        snprintf(s, 32, "%" PRId32, v);
     }
     else if (t == gta::uint32)
     {
         uint32_t v;
         std::memcpy(&v, c, sizeof(uint32_t));
-        snprintf(s, 32, "%"PRIu32, v);
+        snprintf(s, 32, "%" PRIu32, v);
     }
     else if (t == gta::int64)
     {
         int64_t v;
         std::memcpy(&v, c, sizeof(int64_t));
-        snprintf(s, 32, "%"PRId64, v);
+        snprintf(s, 32, "%" PRId64, v);
     }
     else if (t == gta::uint64)
     {
         uint64_t v;
         std::memcpy(&v, c, sizeof(uint64_t));
-        snprintf(s, 32, "%"PRIu64, v);
+        snprintf(s, 32, "%" PRIu64, v);
     }
     else if (t == gta::float32)
     {
@@ -109,7 +111,7 @@ static void write_component(const void* c, gta::type t, char s[32])
     {
         double v;
         std::memcpy(&v, c, sizeof(double));
-        snprintf(s, 32, "%.17f", v);
+        snprintf(s, 32, "%.17g", v);
     }
 }
 
@@ -135,6 +137,8 @@ extern "C" int gtatool_to_csv(int argc, char *argv[])
     try
     {
         std::string nameo = arguments.size() == 1 ? arguments[0] : arguments[1];
+        FILE *fo = fio::open(nameo, "w");
+
         array_loop_t array_loop;
         gta::header hdr;
         std::string name;
@@ -166,9 +170,36 @@ extern "C" int gtatool_to_csv(int argc, char *argv[])
                     throw exc(name + ": unsupported element component type(s).");
                 }
             }
+            if (array_loop.index_in() > 1)
+            {
+                if (std::fputs("\r\n", fo) == EOF)
+                {
+                    throw exc(nameo + ": output error.");
+                }
+            }
+
+            std::vector<blob> no_data_values(checked_cast<size_t>(hdr.components()));
+            for (uintmax_t c = 0; c < hdr.components(); c++)
+            {
+                const char* tagval = hdr.component_taglist(c).get("NO_DATA_VALUE");
+                if (tagval)
+                {
+                    no_data_values[c].resize(hdr.component_size(c));
+                    try
+                    {
+                        value_from_string(std::string(tagval),
+                                hdr.component_type(c), hdr.component_size(c),
+                                no_data_values[c].ptr());
+                    }
+                    catch (std::exception& e)
+                    {
+                        msg::wrn(name + ": component " + str::from(c) + ": invalid NO_DATA_VALUE");
+                        no_data_values[c].free();
+                    }
+                }
+            }
 
             char sbuf[32];
-            FILE *fo = fio::open(nameo, "w");
             element_loop_t element_loop;
             array_loop.start_element_loop(element_loop, hdr, gta::header());
             for (uintmax_t e = 0; e < hdr.elements(); e++)
@@ -176,7 +207,15 @@ extern "C" int gtatool_to_csv(int argc, char *argv[])
                 const void *p = element_loop.read();
                 for (uintmax_t c = 0; c < hdr.components(); c++)
                 {
-                    write_component(hdr.component(p, c), hdr.component_type(c), sbuf);
+                    if (no_data_values[c].size() != 0
+                            && std::memcmp(no_data_values[c].ptr(), hdr.component(p, c), no_data_values[c].size()) == 0)
+                    {
+                        sbuf[0] = '\0';
+                    }
+                    else
+                    {
+                        write_component(hdr.component(p, c), hdr.component_type(c), sbuf);
+                    }
                     if (std::fputs(sbuf, fo) == EOF)
                     {
                         throw exc(nameo + ": output error.");
@@ -202,13 +241,13 @@ extern "C" int gtatool_to_csv(int argc, char *argv[])
                     }
                 }
             }
-            fio::flush(fo, nameo);
-            if (std::ferror(fo))
-            {
-                throw exc(nameo + ": output error.");
-            }
-            fio::close(fo, nameo);
         }
+        fio::flush(fo, nameo);
+        if (std::ferror(fo))
+        {
+            throw exc(nameo + ": output error.");
+        }
+        fio::close(fo, nameo);
         array_loop.finish();
     }
     catch (std::exception &e)
