@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-# Copyright (C) 2010, 2011
+# Copyright (C) 2010, 2011, 2013
 # Martin Lambers <marlam@marlam.de>
 #
 # Copying and distribution of this file, with or without modification, are
@@ -23,4 +23,13 @@ done
 $GTA uncompress "$TMPD"/a.gta > "$TMPD"/a-u.gta
 cmp "$TMPD"/a.gta "$TMPD"/a-u.gta
 
+$GTA create -d 10 > "$TMPD"/empty0.gta
+$GTA create -c uint8 > "$TMPD"/empty1.gta
+$GTA compress "$TMPD"/empty0.gta > "$TMPD"/zempty0.gta
+$GTA uncompress "$TMPD"/zempty0.gta > "$TMPD"/xempty0.gta
+cmp "$TMPD"/empty0.gta "$TMPD"/xempty0.gta
+$GTA compress "$TMPD"/empty1.gta > "$TMPD"/zempty1.gta
+$GTA uncompress "$TMPD"/zempty1.gta > "$TMPD"/xempty1.gta
+cmp "$TMPD"/empty1.gta "$TMPD"/xempty1.gta
+
 rm -r "$TMPD"
